@@ -341,7 +341,7 @@ font_render_get_gconf (GConfClient  *client,
 typedef struct {
   Antialiasing antialiasing;
   Hinting hinting;
-  GtkWidget *radio;
+  GtkToggleButton *radio;
 } FontPair;
 
 static GSList *font_pairs = NULL;
@@ -362,15 +362,16 @@ font_render_load (GConfClient *client)
     FontPair *pair = tmp_list->data;
 
     if (antialiasing == pair->antialiasing && hinting == pair->hinting) {
-      gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (pair->radio), TRUE);
+      gtk_toggle_button_set_active (pair->radio, TRUE);
       inconsistent = FALSE;
+      break;
     }
   }
 
   for (tmp_list = font_pairs; tmp_list; tmp_list = tmp_list->next) {
     FontPair *pair = tmp_list->data;
 
-    gtk_toggle_button_set_inconsistent (GTK_TOGGLE_BUTTON (pair->radio), inconsistent);
+    gtk_toggle_button_set_inconsistent (pair->radio, inconsistent);
   }
 
   in_change = FALSE;
@@ -415,7 +416,7 @@ setup_font_pair (GtkWidget    *radio,
 
   pair->antialiasing = antialiasing;
   pair->hinting = hinting;
-  pair->radio = radio;
+  pair->radio = GTK_TOGGLE_BUTTON (radio);
 
   setup_font_sample (darea, antialiasing, hinting);
   font_pairs = g_slist_prepend (font_pairs, pair);
@@ -580,7 +581,7 @@ typedef struct
 {
   GConfClient *client;
   GSList *items;
-  const gchar *gconf_key;
+  gchar *gconf_key;
   GConfEnumStringPair *enums;
   int default_value;
 } EnumGroup;
@@ -588,7 +589,7 @@ typedef struct
 typedef struct
 {
   EnumGroup *group;
-  GtkWidget *widget;
+  GtkToggleButton *widget;
   int value;
 } EnumItem;
 
@@ -610,7 +611,7 @@ enum_group_load (EnumGroup *group)
     EnumItem *item = tmp_list->data;
 
     if (val == item->value)
-      gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (item->widget), TRUE);
+      gtk_toggle_button_set_active (item->widget, TRUE);
   }
 
   in_change = FALSE;
@@ -668,7 +669,7 @@ enum_group_create (const gchar         *gconf_key,
 
     item = g_new (EnumItem, 1);
     item->group = group;
-    item->widget = widget;
+    item->widget = GTK_TOGGLE_BUTTON (widget);
     item->value = va_arg (args, int);
 
     g_signal_connect (item->widget, "toggled",
@@ -690,6 +691,18 @@ enum_group_create (const gchar         *gconf_key,
   return group;
 }
 
+static void
+enum_group_destroy (EnumGroup *group)
+{
+  g_object_unref (group->client);
+  g_free (group->gconf_key);
+
+  g_slist_foreach (group->items, (GFunc) g_free, NULL);
+  g_slist_free (group->items);
+
+  g_free (group);
+}
+
 static double
 dpi_from_pixels_and_mm (int pixels, int mm)
 {
@@ -792,9 +805,6 @@ cb_details_response (GtkDialog *dialog, gint response_id)
     capplet_help (GTK_WINDOW (dialog),
 		  "user-guide.xml",
 		  "goscustdesk-38");
-  } else if (response_id == 1) {
-    /* "Go to font folder" was clicked */
-    g_spawn_command_line_async ("nautilus --no-desktop fonts:///", NULL);
   } else
     gtk_widget_hide (GTK_WIDGET (dialog));
 }
@@ -804,19 +814,11 @@ cb_show_details (GtkWidget *button,
 		 AppearanceData *data)
 {
   if (!data->font_details) {
-    GnomeVFSURI *uri;
     GtkAdjustment *adjustment;
     GtkWidget *widget;
+    EnumGroup *group;
 
     data->font_details = glade_xml_get_widget (data->xml, "render_details");
-    uri = gnome_vfs_uri_new ("fonts:///");
-    widget = glade_xml_get_widget (data->xml, "go_to_font_button");
-    if (uri == NULL) {
-      gtk_widget_hide (widget);
-    } else {
-      gnome_vfs_uri_unref (uri);
-      gtk_widget_show (widget);
-    }
 
     gtk_window_set_transient_for (GTK_WINDOW (data->font_details),
 				  GTK_WINDOW (glade_xml_get_widget (data->xml, "appearance_window")));
@@ -838,23 +840,27 @@ cb_show_details (GtkWidget *button,
     setup_font_sample (glade_xml_get_widget (data->xml, "antialias_grayscale_sample"), ANTIALIAS_GRAYSCALE, HINT_FULL);
     setup_font_sample (glade_xml_get_widget (data->xml, "antialias_subpixel_sample"),  ANTIALIAS_RGBA,      HINT_FULL);
 
-    enum_group_create (FONT_ANTIALIASING_KEY, antialias_enums, ANTIALIAS_GRAYSCALE,
-		       glade_xml_get_widget (data->xml, "antialias_none_radio"),      ANTIALIAS_NONE,
-		       glade_xml_get_widget (data->xml, "antialias_grayscale_radio"), ANTIALIAS_GRAYSCALE,
-		       glade_xml_get_widget (data->xml, "antialias_subpixel_radio"),  ANTIALIAS_RGBA,
-		       NULL);
+    group = enum_group_create (
+    	FONT_ANTIALIASING_KEY, antialias_enums, ANTIALIAS_GRAYSCALE,
+	glade_xml_get_widget (data->xml, "antialias_none_radio"),      ANTIALIAS_NONE,
+	glade_xml_get_widget (data->xml, "antialias_grayscale_radio"), ANTIALIAS_GRAYSCALE,
+	glade_xml_get_widget (data->xml, "antialias_subpixel_radio"),  ANTIALIAS_RGBA,
+	NULL);
+    data->font_groups = g_slist_prepend (data->font_groups, group);
 
     setup_font_sample (glade_xml_get_widget (data->xml, "hint_none_sample"),   ANTIALIAS_GRAYSCALE, HINT_NONE);
     setup_font_sample (glade_xml_get_widget (data->xml, "hint_slight_sample"), ANTIALIAS_GRAYSCALE, HINT_SLIGHT);
     setup_font_sample (glade_xml_get_widget (data->xml, "hint_medium_sample"), ANTIALIAS_GRAYSCALE, HINT_MEDIUM);
     setup_font_sample (glade_xml_get_widget (data->xml, "hint_full_sample"),   ANTIALIAS_GRAYSCALE, HINT_FULL);
 
-    enum_group_create (FONT_HINTING_KEY, hint_enums, HINT_FULL,
-		       glade_xml_get_widget (data->xml, "hint_none_radio"),   HINT_NONE,
-		       glade_xml_get_widget (data->xml, "hint_slight_radio"), HINT_SLIGHT,
-		       glade_xml_get_widget (data->xml, "hint_medium_radio"), HINT_MEDIUM,
-		       glade_xml_get_widget (data->xml, "hint_full_radio"),   HINT_FULL,
-		       NULL);
+    group = enum_group_create (
+    	FONT_HINTING_KEY, hint_enums, HINT_FULL,
+	glade_xml_get_widget (data->xml, "hint_none_radio"),   HINT_NONE,
+	glade_xml_get_widget (data->xml, "hint_slight_radio"), HINT_SLIGHT,
+	glade_xml_get_widget (data->xml, "hint_medium_radio"), HINT_MEDIUM,
+	glade_xml_get_widget (data->xml, "hint_full_radio"),   HINT_FULL,
+	NULL);
+    data->font_groups = g_slist_prepend (data->font_groups, group);
 
     gtk_image_set_from_file (GTK_IMAGE (glade_xml_get_widget (data->xml, "subpixel_rgb_image")),
 			     GNOMECC_PIXMAP_DIR "/subpixel-rgb.png");
@@ -865,12 +871,14 @@ cb_show_details (GtkWidget *button,
     gtk_image_set_from_file (GTK_IMAGE (glade_xml_get_widget (data->xml, "subpixel_vbgr_image")),
 			     GNOMECC_PIXMAP_DIR "/subpixel-vbgr.png");
 
-    enum_group_create (FONT_RGBA_ORDER_KEY, rgba_order_enums, RGBA_RGB,
-		       glade_xml_get_widget (data->xml, "subpixel_rgb_radio"),  RGBA_RGB,
-		       glade_xml_get_widget (data->xml, "subpixel_bgr_radio"),  RGBA_BGR,
-		       glade_xml_get_widget (data->xml, "subpixel_vrgb_radio"), RGBA_VRGB,
-		       glade_xml_get_widget (data->xml, "subpixel_vbgr_radio"), RGBA_VBGR,
-		       NULL);
+    group = enum_group_create (
+    	FONT_RGBA_ORDER_KEY, rgba_order_enums, RGBA_RGB,
+	glade_xml_get_widget (data->xml, "subpixel_rgb_radio"),  RGBA_RGB,
+	glade_xml_get_widget (data->xml, "subpixel_bgr_radio"),  RGBA_BGR,
+	glade_xml_get_widget (data->xml, "subpixel_vrgb_radio"), RGBA_VRGB,
+	glade_xml_get_widget (data->xml, "subpixel_vbgr_radio"), RGBA_VBGR,
+	NULL);
+    data->font_groups = g_slist_prepend (data->font_groups, group);
 
     g_signal_connect (G_OBJECT (data->font_details),
 		      "response",
@@ -891,6 +899,7 @@ font_init (AppearanceData *data)
   GtkWidget *widget;
 
   data->font_details = NULL;
+  data->font_groups = NULL;
 
   gconf_client_add_dir (data->client, "/desktop/gnome/interface",
 			GCONF_CLIENT_PRELOAD_ONELEVEL, NULL);
@@ -965,6 +974,8 @@ font_init (AppearanceData *data)
 void
 font_shutdown (AppearanceData *data)
 {
+  g_slist_foreach (data->font_groups, (GFunc) enum_group_destroy, NULL);
+  g_slist_free (data->font_groups);
   g_slist_foreach (font_pairs, (GFunc) g_free, NULL);
   g_slist_free (font_pairs);
   g_free (old_font);
