@@ -167,7 +167,6 @@ theme_thumbnail_generate (GnomeThemeMetaInfo *info, AppearanceData *data)
 static void
 theme_changed_on_disk_cb (GnomeThemeCommonInfo *theme,
 			  GnomeThemeChangeType  change_type,
-			  GnomeThemeElement     element,
 			  AppearanceData       *data)
 {
   if (theme->type == GNOME_THEME_TYPE_METATHEME) {
@@ -440,10 +439,18 @@ theme_message_area_response_cb (GtkWidget *w,
         gconf_client_set_string (data->client, APPLICATION_FONT_KEY,
                                  theme->application_font, NULL);
 
+      if (theme->documents_font)
+        gconf_client_set_string (data->client, DOCUMENTS_FONT_KEY,
+                                 theme->documents_font, NULL);
+
       if (theme->desktop_font)
         gconf_client_set_string (data->client, DESKTOP_FONT_KEY,
                                  theme->desktop_font, NULL);
 
+      if (theme->windowtitle_font)
+        gconf_client_set_string (data->client, WINDOWTITLE_FONT_KEY,
+                                 theme->windowtitle_font, NULL);
+
       if (theme->monospace_font)
         gconf_client_set_string (data->client, MONOSPACE_FONT_KEY,
                                  theme->monospace_font, NULL);
@@ -480,6 +487,13 @@ theme_message_area_update (AppearanceData *data)
     g_free (font);
   }
 
+  if (!show_apply_font && theme->documents_font) {
+    font = gconf_client_get_string (data->client, DOCUMENTS_FONT_KEY, NULL);
+    show_apply_font =
+        (!font || strcmp (theme->application_font, font) != 0);
+    g_free (font);
+  }
+
   if (!show_apply_font && theme->desktop_font) {
     font = gconf_client_get_string (data->client, DESKTOP_FONT_KEY, NULL);
     show_apply_font =
@@ -487,6 +501,13 @@ theme_message_area_update (AppearanceData *data)
     g_free (font);
   }
 
+ if (!show_apply_font && theme->windowtitle_font) {
+    font = gconf_client_get_string (data->client, WINDOWTITLE_FONT_KEY, NULL);
+    show_apply_font =
+        (!font || strcmp (theme->application_font, font) != 0);
+    g_free (font);
+  }
+
   if (!show_apply_font && theme->monospace_font) {
     font = gconf_client_get_string (data->client, MONOSPACE_FONT_KEY, NULL);
     show_apply_font =
@@ -924,10 +945,14 @@ themes_init (AppearanceData *data)
   gconf_client_add_dir (data->client, "/desktop/gnome/interface", GCONF_CLIENT_PRELOAD_NONE, NULL);
   gconf_client_notify_add (data->client, METACITY_THEME_KEY, (GConfClientNotifyFunc) theme_gconf_changed, data, NULL, NULL);
   gconf_client_notify_add (data->client, CURSOR_THEME_KEY, (GConfClientNotifyFunc) theme_gconf_changed, data, NULL, NULL);
+#ifdef HAVE_XCURSOR
   gconf_client_notify_add (data->client, CURSOR_SIZE_KEY, (GConfClientNotifyFunc) theme_gconf_changed, data, NULL, NULL);
+#endif
   gconf_client_notify_add (data->client, BACKGROUND_KEY, (GConfClientNotifyFunc) background_or_font_changed, data, NULL, NULL);
   gconf_client_notify_add (data->client, APPLICATION_FONT_KEY, (GConfClientNotifyFunc) background_or_font_changed, data, NULL, NULL);
+  gconf_client_notify_add (data->client, DOCUMENTS_FONT_KEY, (GConfClientNotifyFunc) background_or_font_changed, data, NULL, NULL);
   gconf_client_notify_add (data->client, DESKTOP_FONT_KEY, (GConfClientNotifyFunc) background_or_font_changed, data, NULL, NULL);
+  gconf_client_notify_add (data->client, WINDOWTITLE_FONT_KEY, (GConfClientNotifyFunc) background_or_font_changed, data, NULL, NULL);
   gconf_client_notify_add (data->client, MONOSPACE_FONT_KEY, (GConfClientNotifyFunc) background_or_font_changed, data, NULL, NULL);
 
   settings = gtk_settings_get_default ();
